@@ -8,7 +8,7 @@ use Scalar::Util qw(blessed);
 use Scalar::Util::Numeric qw(isint);
 
 use overload (
-    q{0+} => sub { confess "Can't numerify an AlignDB::IntSpan\n" },
+    q{0+}   => sub { confess "Can't numerify an AlignDB::IntSpan\n" },
     q{bool} => q{is_not_empty},
     q{""}   => q{runlist},
 
@@ -16,7 +16,7 @@ use overload (
     fallback => 1,
 );
 
-our $VERSION = '1.0.3';
+our $VERSION = '1.0.6';
 
 Readonly my $POS_INF => 2_147_483_647 - 1;             # INT_MAX - 1
 Readonly my $NEG_INF => ( -2_147_483_647 - 1 ) + 1;    # INT_MIN + 1
@@ -87,10 +87,10 @@ sub as_string {
     }
 
     my @runs;
-    my @ranges = $self->ranges;
-    while (@ranges) {
-        my $lower = shift @ranges;
-        my $upper = shift @ranges;
+    my @edges = $self->edges;
+    while (@edges) {
+        my $lower = shift @edges;
+        my $upper = shift(@edges) - 1;
         push @runs, $lower == $upper ? $lower : "$lower-$upper";
     }
 
@@ -101,10 +101,10 @@ sub as_array {
     my $self = shift;
 
     my @elements;
-    my @ranges = $self->ranges;
-    while (@ranges) {
-        my $lower = shift @ranges;
-        my $upper = shift @ranges;
+    my @edges = $self->edges;
+    while (@edges) {
+        my $lower = shift @edges;
+        my $upper = shift(@edges) - 1;
         push @elements, ( $lower .. $upper );
     }
 
@@ -129,10 +129,10 @@ sub spans {
     my $self = shift;
 
     my @spans;
-    my @ranges = $self->ranges;
-    while (@ranges) {
-        my $lower = shift @ranges;
-        my $upper = shift @ranges;
+    my @edges = $self->edges;
+    while (@edges) {
+        my $lower = shift @edges;
+        my $upper = shift(@edges) - 1;
         push @spans, [ $lower, $upper ];
     }
 
@@ -143,10 +143,10 @@ sub sets {
     my $self = shift;
 
     my @sets;
-    my @ranges = $self->ranges;
-    while (@ranges) {
-        my $lower = shift @ranges;
-        my $upper = shift @ranges;
+    my @edges = $self->edges;
+    while (@edges) {
+        my $lower = shift @edges;
+        my $upper = shift(@edges) - 1;
         push @sets, blessed($self)->new("$lower-$upper");
     }
 
@@ -161,10 +161,10 @@ sub runlists {
     }
 
     my @runlists;
-    my @ranges = $self->ranges;
-    while (@ranges) {
-        my $lower  = shift @ranges;
-        my $upper  = shift @ranges;
+    my @edges = $self->edges;
+    while (@edges) {
+        my $lower  = shift @edges;
+        my $upper  = shift(@edges) - 1;
         my $string = $lower == $upper ? $lower : $lower . '-' . $upper;
         push @runlists, $string;
     }
@@ -176,10 +176,10 @@ sub cardinality {
     my $self = shift;
 
     my $cardinality = 0;
-    my @ranges      = $self->ranges;
-    while (@ranges) {
-        my $lower = shift @ranges;
-        my $upper = shift @ranges;
+    my @edges       = $self->edges;
+    while (@edges) {
+        my $lower = shift @edges;
+        my $upper = shift(@edges) - 1;
         $cardinality += $upper - $lower + 1;
     }
 
@@ -389,7 +389,7 @@ sub remove {
 sub merge {
     my $self = shift;
 
-    foreach my $supplied (@_) {
+    for my $supplied (@_) {
         my @ranges = $self->_real_set($supplied)->ranges;
         $self->add_range(@ranges);
     }
@@ -399,8 +399,9 @@ sub merge {
 
 sub subtract {
     my $self = shift;
+    return $self if $self->is_empty;
 
-    foreach my $supplied (@_) {
+    for my $supplied (@_) {
         my @ranges = $self->_real_set($supplied)->ranges;
         $self->remove_range(@ranges);
     }
@@ -438,6 +439,8 @@ sub complement {
 sub diff {
     my $self = shift;
 
+    return $self if $self->is_empty;
+
     my $new = $self->copy;
     $new->subtract(@_);
 
@@ -447,6 +450,8 @@ sub diff {
 sub intersect {
     my $self = shift;
 
+    return $self if $self->is_empty;
+
     my $new = $self->complement;
     for my $supplied (@_) {
         my $temp_set = $self->_real_set($supplied)->complement;
@@ -522,8 +527,7 @@ sub at {
     if ( $index == 0 || abs($index) > $self->cardinality ) {
         return;
     }
-    my $member
-        = $index < 0 ? $self->_at_neg( -$index ) : $self->_at_pos($index);
+    my $member = $index < 0 ? $self->_at_neg( -$index ) : $self->_at_pos($index);
     return $member;
 }
 
@@ -534,10 +538,10 @@ sub _at_pos {
     my $member;
     my $element_before = 0;
 
-    my @ranges = $self->ranges;
-    while (@ranges) {
-        my $lower     = shift @ranges;
-        my $upper     = shift @ranges;
+    my @edges = $self->edges;
+    while (@edges) {
+        my $lower     = shift @edges;
+        my $upper     = shift(@edges) - 1;
         my $span_size = $upper - $lower + 1;
 
         if ( $index > $element_before + $span_size ) {
@@ -559,10 +563,10 @@ sub _at_neg {
     my $member;
     my $element_after = 0;
 
-    my @r_ranges = reverse $self->ranges;
-    while (@r_ranges) {
-        my $upper     = shift @r_ranges;
-        my $lower     = shift @r_ranges;
+    my @r_edges = reverse $self->edges;
+    while (@r_edges) {
+        my $upper     = shift(@r_edges) - 1;
+        my $lower     = shift @r_edges;
         my $span_size = $upper - $lower + 1;
 
         if ( $index > $element_after + $span_size ) {
@@ -584,10 +588,10 @@ sub index {
     my $index;
     my $element_before = 0;
 
-    my @ranges = $self->ranges;
-    while (@ranges) {
-        my $lower     = shift @ranges;
-        my $upper     = shift @ranges;
+    my @edges = $self->edges;
+    while (@edges) {
+        my $lower     = shift @edges;
+        my $upper     = shift(@edges) - 1;
         my $span_size = $upper - $lower + 1;
 
         if ( $member >= $lower and $member <= $upper ) {
@@ -732,7 +736,7 @@ sub map_set {
 
     my @map_elements;
     for ( $self->elements ) {
-        foreach my $element ( $code_ref->() ) {
+        for my $element ( $code_ref->() ) {
             if ( defined $element ) {
                 push @map_elements, $element;
             }
@@ -751,7 +755,7 @@ sub substr_span {
     my $sub_string = "";
     my @spans      = $self->spans;
 
-    foreach (@spans) {
+    for (@spans) {
         my ( $lower, $upper ) = @$_;
         my $length = $upper - $lower + 1;
 
@@ -804,7 +808,6 @@ sub holes {
 
         # Remove infinite arms of complement set
         if ( $c_set->is_neg_inf ) {
-
             shift @ranges;
             shift @ranges;
         }
@@ -822,11 +825,11 @@ sub inset {
     my $self = shift;
     my $n    = shift;
 
-    my $inset  = blessed($self)->new;
-    my @ranges = $self->ranges;
-    while (@ranges) {
-        my $lower = shift @ranges;
-        my $upper = shift @ranges;
+    my $inset = blessed($self)->new;
+    my @edges = $self->edges;
+    while (@edges) {
+        my $lower = shift @edges;
+        my $upper = shift(@edges) - 1;
         if ( $lower != $self->NEG_INF ) {
             $lower += $n;
         }
@@ -1095,19 +1098,18 @@ sub _find_pos {
 # Aliases
 #----------------------------------------------------------#
 
-sub runlist       { shift->as_string(@_); }
-sub run_list      { shift->as_string(@_); }
-sub elements      { shift->as_array(@_); }
-sub size          { shift->cardinality(@_); }
-sub count         { shift->cardinality(@_); }
-sub empty         { shift->is_empty; }
-sub contains      { shift->contains_all(@_); }
-sub contain       { shift->contains_all(@_); }
-sub member        { shift->contains_all(@_); }
-sub duplicate     { shift->copy; }
-sub intersection  { shift->intersect(@_); }
-sub equals        { shift->equal(@_); }
-sub join_span     { shift->fill(@_); }
+sub runlist      { shift->as_string(@_); }
+sub run_list     { shift->as_string(@_); }
+sub elements     { shift->as_array(@_); }
+sub size         { shift->cardinality(@_); }
+sub count        { shift->cardinality(@_); }
+sub empty        { shift->is_empty; }
+sub contains     { shift->contains_all(@_); }
+sub contain      { shift->contains_all(@_); }
+sub member       { shift->contains_all(@_); }
+sub duplicate    { shift->copy; }
+sub intersection { shift->intersect(@_); }
+sub equals       { shift->equal(@_); }
 
 1;    # Magic true value required at end of module
 
@@ -1466,10 +1468,6 @@ Returns true if $set is larger than $set_spec.
 Returns the indexth element of set, index start from "1".
 Negtive indices count backwards from the end of the set.
 
-=head2 lookup_back_index
-
-Give an backword index, return a element
-
 =head2 index
 
 Returns the index fo a element in the set, index start from "1"
@@ -1628,8 +1626,6 @@ from the last island (c.f. negative indexes of Perl arrays).
 
     equals                      => equal
 
-    join_span                   => fill
-
 =head1 AUTHOR
 
 Qiang Wang <wang-q@outlook.com>
